@@ -1,15 +1,15 @@
 
 /*
- *  Time-stamp:      "2002-09-21 10:54:11 bkorb"
+ *  Time-stamp:      "2003-04-28 18:41:25 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.27 2002/09/21 19:35:40 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 2.36 2003/04/29 01:42:37 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -55,12 +55,14 @@
 #define AUTOGEN_AUTOOPTS_H
 
 #define __EXTENSIONS__
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#  include "compat/compat.h"
-#endif
 
+#include "config.h"
+#include "compat/compat.h"
 #include <sys/param.h>
+#include <sys/wait.h>
+#include <time.h>
+#include <utime.h>
+
 #include "options.h"
 #include "streqv.h"
 
@@ -69,9 +71,6 @@
  */
 #define NUM_TO_VER(n)       ((n) >> 12), ((n) >> 7) & 0x001F, (n) & 0x007F
 
-/*
- */
-
 #define NAMED_OPTS(po) \
         (((po)->fOptSet & (OPTPROC_SHORTOPT | OPTPROC_LONGOPT)) == 0)
 
@@ -155,6 +154,11 @@ typedef struct {
 #  define TAGMEM( m, t )
 
 
+/*
+ *  File pointer for usage output
+ */
+extern FILE* option_usage_fp;
+
 /*
  *  optionUsage print the usage text for the program described by the
  *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
@@ -180,10 +184,14 @@ ag_bool optionMakePath PROTO((
     tCC*     pzName,
     tCC*     pzProgPath ));
 
+extern tOptProc doVersion, doPagedUsage, doLoadOpt;
+
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * autoopts.h ends here */
+ * end of autoopts/autoopts.h */
