@@ -1,6 +1,6 @@
 
 /*
- *  $Id: enumeration.c,v 2.9 2002/04/14 22:30:30 bkorb Exp $
+ *  $Id: enumeration.c,v 2.20 2003/05/03 16:13:53 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,13 +51,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <memory.h>
-
-#include "autoopts.h"
-
 tSCC*  pz_fmt;
 
 static void
@@ -68,9 +61,10 @@ enumError( pOpts, pOD, paz_names, name_ct )
     int       name_ct;
 {
     if (pOpts != NULL)
-        fprintf( stderr, pz_fmt, pOpts->pzProgName, pOD->pzLastArg );
+        fprintf( option_usage_fp, pz_fmt, pOpts->pzProgName, pOD->pzLastArg );
 
-    fprintf( stderr, "The valid %s option keywords are:\n", pOD->pz_Name );
+    fprintf( option_usage_fp, "The valid %s option keywords are:\n",
+             pOD->pz_Name );
 
     if (**paz_names == 0x7F) {
         paz_names++;
@@ -78,7 +72,7 @@ enumError( pOpts, pOD, paz_names, name_ct )
     }
 
     do  {
-        fprintf( stderr, "\t%s\n", *(paz_names++) );
+        fprintf( option_usage_fp, "\t%s\n", *(paz_names++) );
     } while (--name_ct > 0);
 
     if (pOpts != NULL)
@@ -111,25 +105,35 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
     tCC**     paz_names;
     int       name_ct;
 {
-    size_t  len;
-    int     idx;
-    int     res = -1;
+    size_t      len;
+    int         idx;
+    uintptr_t   res = (uintptr_t)~0;
 
     /*
-     *  IF there is no option struct pointer, then we are being
-     *  called (indirectly) by the usage or putshell routine.
-     *  They want the keyword or keyword list to be printed.
-     *  The returned result is ignored.
+     *  IF the program option descriptor pointer is invalid,
+     *  then it is some sort of special request.
      */
     switch ((u_long)pOpts) {
     case 0UL:
+        /*
+         *  print the list of enumeration names.
+         */
         enumError( pOpts, pOD, paz_names, name_ct );
         return (char*)0UL;
 
     case 1UL:
+        /*
+         *  print the name string.
+         */
         fputs( paz_names[ (int)(pOD->pzLastArg) ], stdout );
         return (char*)0UL;
 
+    case 2UL:
+        /*
+         *  Replace the enumeration value with the name string.
+         */
+        return (char*)paz_names[ (uintptr_t)(pOD->pzLastArg) ];
+
     default:
         break;
     }
@@ -146,6 +150,7 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
                 return (char*)idx;
             if (res != -1) {
                 pz_fmt = "%s error:  the keyword `%s' is ambiguous\n";
+                option_usage_fp = stderr;
                 enumError( pOpts, pOD, paz_names, name_ct );
             }
             res = idx;
@@ -154,6 +159,7 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
 
     if (res < 0) {
         pz_fmt = "%s error:  `%s' does not match any keywords\n";
+        option_usage_fp = stderr;
         enumError( pOpts, pOD, paz_names, name_ct );
     }
 
@@ -166,7 +172,9 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * pgusage.c ends here */
+ * end of autoopts/enumeration.c */
